# This file was created automatically by SWIG.
import windowsc

from misc import *

from gdi import *

from fonts import *

from clip_dnd import *
import wx

def wxDLG_PNT(win, point_or_x, y=None):
    if y is None:
        return win.ConvertDialogPointToPixels(point_or_x)
    else:
        return win.ConvertDialogPointToPixels(wxPoint(point_or_x, y))

def wxDLG_SZE(win, size_width, height=None):
    if height is None:
        return win.ConvertDialogSizeToPixels(size_width)
    else:
        return win.ConvertDialogSizeToPixels(wxSize(size_width, height))

class wxEvtHandlerPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def ProcessEvent(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_ProcessEvent,(self,) + _args, _kwargs)
        return val
    def AddPendingEvent(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_AddPendingEvent,(self,) + _args, _kwargs)
        return val
    def GetEvtHandlerEnabled(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_GetEvtHandlerEnabled,(self,) + _args, _kwargs)
        return val
    def SetEvtHandlerEnabled(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_SetEvtHandlerEnabled,(self,) + _args, _kwargs)
        return val
    def GetNextHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_GetNextHandler,(self,) + _args, _kwargs)
        return val
    def GetPreviousHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_GetPreviousHandler,(self,) + _args, _kwargs)
        return val
    def SetNextHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_SetNextHandler,(self,) + _args, _kwargs)
        return val
    def SetPreviousHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_SetPreviousHandler,(self,) + _args, _kwargs)
        return val
    def Connect(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_Connect,(self,) + _args, _kwargs)
        return val
    def Disconnect(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler_Disconnect,(self,) + _args, _kwargs)
        return val
    def _setOORInfo(self, *_args, **_kwargs):
        val = apply(windowsc.wxEvtHandler__setOORInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxEvtHandler instance at %s>" % (self.this,)
class wxEvtHandler(wxEvtHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxEvtHandler,_args,_kwargs)
        self.thisown = 1




class wxValidatorPtr(wxEvtHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Clone(self, *_args, **_kwargs):
        val = apply(windowsc.wxValidator_Clone,(self,) + _args, _kwargs)
        return val
    def GetWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxValidator_GetWindow,(self,) + _args, _kwargs)
        return val
    def SetWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxValidator_SetWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxValidator instance at %s>" % (self.this,)
class wxValidator(wxValidatorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxValidator,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxPyValidatorPtr(wxValidatorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(windowsc.wxPyValidator__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyValidator instance at %s>" % (self.this,)
class wxPyValidator(wxPyValidatorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxPyValidator,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyValidator, 1)
        self._setOORInfo(self)




class wxWindowPtr(wxEvtHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Create,(self,) + _args, _kwargs)
        return val
    def Center(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Center,(self,) + _args, _kwargs)
        return val
    def Centre(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Centre,(self,) + _args, _kwargs)
        return val
    def CentreOnParent(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_CentreOnParent,(self,) + _args, _kwargs)
        return val
    def CenterOnParent(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_CenterOnParent,(self,) + _args, _kwargs)
        return val
    def CentreOnScreen(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_CentreOnScreen,(self,) + _args, _kwargs)
        return val
    def CenterOnScreen(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_CenterOnScreen,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Clear,(self,) + _args, _kwargs)
        return val
    def ClientToScreenXY(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ClientToScreenXY,(self,) + _args, _kwargs)
        return val
    def ClientToScreen(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ClientToScreen,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def Close(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Close,(self,) + _args, _kwargs)
        return val
    def Destroy(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Destroy,(self,) + _args, _kwargs)
        return val
    def DestroyChildren(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_DestroyChildren,(self,) + _args, _kwargs)
        return val
    def IsBeingDeleted(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_IsBeingDeleted,(self,) + _args, _kwargs)
        return val
    def Enable(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Enable,(self,) + _args, _kwargs)
        return val
    def Disable(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Disable,(self,) + _args, _kwargs)
        return val
    def FindWindowById(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_FindWindowById,(self,) + _args, _kwargs)
        return val
    def FindWindowByName(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_FindWindowByName,(self,) + _args, _kwargs)
        return val
    def Fit(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Fit,(self,) + _args, _kwargs)
        return val
    def FitInside(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_FitInside,(self,) + _args, _kwargs)
        return val
    def GetBackgroundColour(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetBackgroundColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetBorder(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetBorder,(self,) + _args, _kwargs)
        return val
    def GetChildren(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetChildren,(self,) + _args, _kwargs)
        return val
    def GetCharHeight(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetCharHeight,(self,) + _args, _kwargs)
        return val
    def GetCharWidth(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetCharWidth,(self,) + _args, _kwargs)
        return val
    def GetClientSizeTuple(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetClientSizeTuple,(self,) + _args, _kwargs)
        return val
    def GetClientSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetClientSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetClientAreaOrigin(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetClientAreaOrigin,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetClientRect(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetClientRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def GetConstraints(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetConstraints,(self,) + _args, _kwargs)
        if val: val = wxLayoutConstraintsPtr(val) 
        return val
    def GetEventHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetEventHandler,(self,) + _args, _kwargs)
        return val
    def GetFont(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def GetForegroundColour(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetForegroundColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetGrandParent(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetGrandParent,(self,) + _args, _kwargs)
        return val
    def GetHandle(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetHandle,(self,) + _args, _kwargs)
        return val
    def GetId(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetId,(self,) + _args, _kwargs)
        return val
    def GetLabel(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetLabel,(self,) + _args, _kwargs)
        return val
    def SetLabel(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetLabel,(self,) + _args, _kwargs)
        return val
    def GetName(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetName,(self,) + _args, _kwargs)
        return val
    def GetParent(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetParent,(self,) + _args, _kwargs)
        return val
    def GetPositionTuple(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetPositionTuple,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetRect(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def GetScrollThumb(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetScrollThumb,(self,) + _args, _kwargs)
        return val
    def GetScrollPos(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetScrollPos,(self,) + _args, _kwargs)
        return val
    def GetScrollRange(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetScrollRange,(self,) + _args, _kwargs)
        return val
    def GetSizeTuple(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetSizeTuple,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetTextExtent(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetTextExtent,(self,) + _args, _kwargs)
        return val
    def GetFullTextExtent(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetFullTextExtent,(self,) + _args, _kwargs)
        return val
    def GetTitle(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetTitle,(self,) + _args, _kwargs)
        return val
    def GetUpdateRegion(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetUpdateRegion,(self,) + _args, _kwargs)
        if val: val = wxRegionPtr(val) ; val.thisown = 1
        return val
    def GetWindowStyleFlag(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetWindowStyleFlag,(self,) + _args, _kwargs)
        return val
    def SetWindowStyleFlag(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetWindowStyleFlag,(self,) + _args, _kwargs)
        return val
    def SetWindowStyle(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetWindowStyle,(self,) + _args, _kwargs)
        return val
    def HasScrollbar(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_HasScrollbar,(self,) + _args, _kwargs)
        return val
    def Hide(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Hide,(self,) + _args, _kwargs)
        return val
    def HitTest(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_HitTest,(self,) + _args, _kwargs)
        return val
    def InitDialog(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_InitDialog,(self,) + _args, _kwargs)
        return val
    def IsEnabled(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_IsEnabled,(self,) + _args, _kwargs)
        return val
    def IsExposed(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_IsExposed,(self,) + _args, _kwargs)
        return val
    def IsExposedPoint(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_IsExposedPoint,(self,) + _args, _kwargs)
        return val
    def IsExposedRect(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_IsExposedRect,(self,) + _args, _kwargs)
        return val
    def IsRetained(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_IsRetained,(self,) + _args, _kwargs)
        return val
    def IsShown(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_IsShown,(self,) + _args, _kwargs)
        return val
    def IsTopLevel(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_IsTopLevel,(self,) + _args, _kwargs)
        return val
    def Layout(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Layout,(self,) + _args, _kwargs)
        return val
    def Lower(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Lower,(self,) + _args, _kwargs)
        return val
    def MakeModal(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_MakeModal,(self,) + _args, _kwargs)
        return val
    def MoveXY(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_MoveXY,(self,) + _args, _kwargs)
        return val
    def Move(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Move,(self,) + _args, _kwargs)
        return val
    def PopEventHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_PopEventHandler,(self,) + _args, _kwargs)
        return val
    def PushEventHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_PushEventHandler,(self,) + _args, _kwargs)
        return val
    def RemoveEventHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_RemoveEventHandler,(self,) + _args, _kwargs)
        return val
    def PopupMenuXY(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_PopupMenuXY,(self,) + _args, _kwargs)
        return val
    def PopupMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_PopupMenu,(self,) + _args, _kwargs)
        return val
    def Raise(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Raise,(self,) + _args, _kwargs)
        return val
    def Refresh(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Refresh,(self,) + _args, _kwargs)
        return val
    def RefreshRect(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_RefreshRect,(self,) + _args, _kwargs)
        return val
    def AddChild(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_AddChild,(self,) + _args, _kwargs)
        return val
    def RemoveChild(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_RemoveChild,(self,) + _args, _kwargs)
        return val
    def Reparent(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Reparent,(self,) + _args, _kwargs)
        return val
    def ScreenToClientXY(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ScreenToClientXY,(self,) + _args, _kwargs)
        return val
    def ScreenToClient(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ScreenToClient,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def ScrollWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ScrollWindow,(self,) + _args, _kwargs)
        return val
    def SetAutoLayout(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetAutoLayout,(self,) + _args, _kwargs)
        return val
    def GetAutoLayout(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetAutoLayout,(self,) + _args, _kwargs)
        return val
    def SetBackgroundColour(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetConstraints(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetConstraints,(self,) + _args, _kwargs)
        return val
    def UnsetConstraints(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_UnsetConstraints,(self,) + _args, _kwargs)
        return val
    def SetFocus(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetFocus,(self,) + _args, _kwargs)
        return val
    def SetFocusFromKbd(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetFocusFromKbd,(self,) + _args, _kwargs)
        return val
    def AcceptsFocus(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_AcceptsFocus,(self,) + _args, _kwargs)
        return val
    def SetFont(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetFont,(self,) + _args, _kwargs)
        return val
    def SetForegroundColour(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetForegroundColour,(self,) + _args, _kwargs)
        return val
    def SetId(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetId,(self,) + _args, _kwargs)
        return val
    def SetName(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetName,(self,) + _args, _kwargs)
        return val
    def SetScrollbar(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetScrollbar,(self,) + _args, _kwargs)
        return val
    def SetScrollPos(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetScrollPos,(self,) + _args, _kwargs)
        return val
    def SetDimensions(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetDimensions,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetSize,(self,) + _args, _kwargs)
        return val
    def SetPosition(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetPosition,(self,) + _args, _kwargs)
        return val
    def SetRect(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetRect,(self,) + _args, _kwargs)
        return val
    def SetSizeHints(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetSizeHints,(self,) + _args, _kwargs)
        return val
    def SetVirtualSizeHints(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetVirtualSizeHints,(self,) + _args, _kwargs)
        return val
    def SetVirtualSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetVirtualSize,(self,) + _args, _kwargs)
        return val
    def SetVirtualSizeWH(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetVirtualSizeWH,(self,) + _args, _kwargs)
        return val
    def GetVirtualSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetVirtualSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetVirtualSizeTuple(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetVirtualSizeTuple,(self,) + _args, _kwargs)
        return val
    def GetBestVirtualSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetBestVirtualSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def SetClientSizeWH(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetClientSizeWH,(self,) + _args, _kwargs)
        return val
    def SetClientSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetClientSize,(self,) + _args, _kwargs)
        return val
    def SetCursor(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetCursor,(self,) + _args, _kwargs)
        return val
    def GetCursor(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetCursor,(self,) + _args, _kwargs)
        if val: val = wxCursorPtr(val) 
        return val
    def SetEventHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetEventHandler,(self,) + _args, _kwargs)
        return val
    def SetExtraStyle(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetExtraStyle,(self,) + _args, _kwargs)
        return val
    def SetTitle(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetTitle,(self,) + _args, _kwargs)
        return val
    def Show(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Show,(self,) + _args, _kwargs)
        return val
    def TransferDataFromWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_TransferDataFromWindow,(self,) + _args, _kwargs)
        return val
    def TransferDataToWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_TransferDataToWindow,(self,) + _args, _kwargs)
        return val
    def UpdateWindowUI(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_UpdateWindowUI,(self,) + _args, _kwargs)
        return val
    def Validate(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Validate,(self,) + _args, _kwargs)
        return val
    def ConvertDialogPointToPixels(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ConvertDialogPointToPixels,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def ConvertDialogSizeToPixels(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ConvertDialogSizeToPixels,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def DLG_PNT(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_DLG_PNT,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def DLG_SZE(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_DLG_SZE,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def ConvertPixelPointToDialog(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ConvertPixelPointToDialog,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def ConvertPixelSizeToDialog(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ConvertPixelSizeToDialog,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def SetToolTipString(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetToolTipString,(self,) + _args, _kwargs)
        return val
    def SetToolTip(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetToolTip,(self,) + _args, _kwargs)
        return val
    def GetToolTip(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetToolTip,(self,) + _args, _kwargs)
        return val
    def SetSizer(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetSizer,(self,) + _args, _kwargs)
        return val
    def SetSizerAndFit(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetSizerAndFit,(self,) + _args, _kwargs)
        return val
    def GetSizer(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetSizer,(self,) + _args, _kwargs)
        return val
    def SetContainingSizer(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetContainingSizer,(self,) + _args, _kwargs)
        return val
    def GetContainingSizer(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetContainingSizer,(self,) + _args, _kwargs)
        return val
    def GetValidator(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetValidator,(self,) + _args, _kwargs)
        return val
    def SetValidator(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetValidator,(self,) + _args, _kwargs)
        return val
    def SetDropTarget(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetDropTarget,(self,) + _args, _kwargs)
        _args[0].thisown = 0
        return val
    def GetDropTarget(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetDropTarget,(self,) + _args, _kwargs)
        if val: val = wxDropTargetPtr(val) 
        return val
    def GetBestSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetBestSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetMaxSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetMaxSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetAdjustedBestSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetAdjustedBestSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def SetCaret(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetCaret,(self,) + _args, _kwargs)
        return val
    def GetCaret(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetCaret,(self,) + _args, _kwargs)
        if val: val = wxCaretPtr(val) 
        return val
    def Freeze(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Freeze,(self,) + _args, _kwargs)
        return val
    def Thaw(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Thaw,(self,) + _args, _kwargs)
        return val
    def Update(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_Update,(self,) + _args, _kwargs)
        return val
    def GetHelpText(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetHelpText,(self,) + _args, _kwargs)
        return val
    def SetHelpText(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetHelpText,(self,) + _args, _kwargs)
        return val
    def SetHelpTextForId(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetHelpTextForId,(self,) + _args, _kwargs)
        return val
    def ScrollLines(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ScrollLines,(self,) + _args, _kwargs)
        return val
    def ScrollPages(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ScrollPages,(self,) + _args, _kwargs)
        return val
    def LineUp(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_LineUp,(self,) + _args, _kwargs)
        return val
    def LineDown(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_LineDown,(self,) + _args, _kwargs)
        return val
    def PageUp(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_PageUp,(self,) + _args, _kwargs)
        return val
    def PageDown(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_PageDown,(self,) + _args, _kwargs)
        return val
    def SetAcceleratorTable(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetAcceleratorTable,(self,) + _args, _kwargs)
        return val
    def GetAcceleratorTable(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetAcceleratorTable,(self,) + _args, _kwargs)
        if val: val = wxAcceleratorTablePtr(val) 
        return val
    def GetDefaultItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_GetDefaultItem,(self,) + _args, _kwargs)
        return val
    def SetDefaultItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetDefaultItem,(self,) + _args, _kwargs)
        return val
    def SetTmpDefaultItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_SetTmpDefaultItem,(self,) + _args, _kwargs)
        return val
    def WarpPointer(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_WarpPointer,(self,) + _args, _kwargs)
        return val
    def CaptureMouse(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_CaptureMouse,(self,) + _args, _kwargs)
        return val
    def ReleaseMouse(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_ReleaseMouse,(self,) + _args, _kwargs)
        return val
    def HasCapture(self, *_args, **_kwargs):
        val = apply(windowsc.wxWindow_HasCapture,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxWindow instance at %s>" % (self.this,)
    # replaces broken shadow method
    def GetCaret(self, *_args, **_kwargs):
        from misc2 import wxCaretPtr
        val = apply(windowsc.wxWindow_GetCaret,(self,) + _args, _kwargs)
        if val: val = wxCaretPtr(val)
        return val
    
class wxWindow(wxWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreWindow(*_args,**_kwargs):
    val = wxWindowPtr(apply(windowsc.new_wxPreWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxPanelPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(windowsc.wxPanel_Create,(self,) + _args, _kwargs)
        return val
    def InitDialog(self, *_args, **_kwargs):
        val = apply(windowsc.wxPanel_InitDialog,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPanel instance at %s>" % (self.this,)
class wxPanel(wxPanelPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxPanel,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPrePanel(*_args,**_kwargs):
    val = wxPanelPtr(apply(windowsc.new_wxPrePanel,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxScrolledWindowPtr(wxPanelPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_Create,(self,) + _args, _kwargs)
        return val
    def EnableScrolling(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_EnableScrolling,(self,) + _args, _kwargs)
        return val
    def GetScrollPageSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_GetScrollPageSize,(self,) + _args, _kwargs)
        return val
    def GetScrollPixelsPerUnit(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_GetScrollPixelsPerUnit,(self,) + _args, _kwargs)
        return val
    def GetTargetWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_GetTargetWindow,(self,) + _args, _kwargs)
        return val
    def IsRetained(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_IsRetained,(self,) + _args, _kwargs)
        return val
    def PrepareDC(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_PrepareDC,(self,) + _args, _kwargs)
        return val
    def Scroll(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_Scroll,(self,) + _args, _kwargs)
        return val
    def SetScrollbars(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_SetScrollbars,(self,) + _args, _kwargs)
        return val
    def SetScrollPageSize(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_SetScrollPageSize,(self,) + _args, _kwargs)
        return val
    def SetTargetWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_SetTargetWindow,(self,) + _args, _kwargs)
        return val
    def GetViewStart(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_GetViewStart,(self,) + _args, _kwargs)
        return val
    def CalcScrolledPosition1(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_CalcScrolledPosition1,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def CalcScrolledPosition2(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_CalcScrolledPosition2,(self,) + _args, _kwargs)
        return val
    def CalcUnscrolledPosition1(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_CalcUnscrolledPosition1,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def CalcUnscrolledPosition2(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_CalcUnscrolledPosition2,(self,) + _args, _kwargs)
        return val
    def SetScale(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_SetScale,(self,) + _args, _kwargs)
        return val
    def GetScaleX(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_GetScaleX,(self,) + _args, _kwargs)
        return val
    def GetScaleY(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_GetScaleY,(self,) + _args, _kwargs)
        return val
    def AdjustScrollbars(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_AdjustScrollbars,(self,) + _args, _kwargs)
        return val
    def Layout(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_Layout,(self,) + _args, _kwargs)
        return val
    def SetScrollRate(self, *_args, **_kwargs):
        val = apply(windowsc.wxScrolledWindow_SetScrollRate,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxScrolledWindow instance at %s>" % (self.this,)
    ViewStart = GetViewStart
    
    def CalcScrolledPosition(self, *args):
        if len(args) == 1:
            return apply(self.CalcScrolledPosition1, args)
        elif len(args) == 2:
            return apply(self.CalcScrolledPosition2, args)
        else:
            raise TypeError, 'Invalid parameters: only (x,y) or (point) allowed'

    def CalcUnscrolledPosition(self, *args):
        if len(args) == 1:
            return apply(self.CalcUnscrolledPosition1, args)
        elif len(args) == 2:
            return apply(self.CalcUnscrolledPosition2, args)
        else:
            raise TypeError, 'Invalid parameters: only (x,y) or (point) allowed'

class wxScrolledWindow(wxScrolledWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxScrolledWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreScrolledWindow(*_args,**_kwargs):
    val = wxScrolledWindowPtr(apply(windowsc.new_wxPreScrolledWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxMenuPtr(wxEvtHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Append(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Append,(self,) + _args, _kwargs)
        return val
    def AppendMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_AppendMenu,(self,) + _args, _kwargs)
        return val
    def AppendItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_AppendItem,(self,) + _args, _kwargs)
        return val
    def AppendCheckItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_AppendCheckItem,(self,) + _args, _kwargs)
        return val
    def AppendRadioItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_AppendRadioItem,(self,) + _args, _kwargs)
        return val
    def AppendSeparator(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_AppendSeparator,(self,) + _args, _kwargs)
        return val
    def Insert(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Insert,(self,) + _args, _kwargs)
        return val
    def InsertSeparator(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_InsertSeparator,(self,) + _args, _kwargs)
        return val
    def InsertCheckItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_InsertCheckItem,(self,) + _args, _kwargs)
        return val
    def InsertRadioItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_InsertRadioItem,(self,) + _args, _kwargs)
        return val
    def InsertMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_InsertMenu,(self,) + _args, _kwargs)
        return val
    def InsertItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_InsertItem,(self,) + _args, _kwargs)
        return val
    def Prepend(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Prepend,(self,) + _args, _kwargs)
        return val
    def PrependSeparator(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_PrependSeparator,(self,) + _args, _kwargs)
        return val
    def PrependCheckItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_PrependCheckItem,(self,) + _args, _kwargs)
        return val
    def PrependRadioItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_PrependRadioItem,(self,) + _args, _kwargs)
        return val
    def PrependMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_PrependMenu,(self,) + _args, _kwargs)
        return val
    def PrependItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_PrependItem,(self,) + _args, _kwargs)
        return val
    def Break(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Break,(self,) + _args, _kwargs)
        return val
    def Check(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Check,(self,) + _args, _kwargs)
        return val
    def IsChecked(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_IsChecked,(self,) + _args, _kwargs)
        return val
    def Enable(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Enable,(self,) + _args, _kwargs)
        return val
    def IsEnabled(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_IsEnabled,(self,) + _args, _kwargs)
        return val
    def FindItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_FindItem,(self,) + _args, _kwargs)
        return val
    def FindItemById(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_FindItemById,(self,) + _args, _kwargs)
        return val
    def GetTitle(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetTitle,(self,) + _args, _kwargs)
        return val
    def SetTitle(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_SetTitle,(self,) + _args, _kwargs)
        return val
    def GetLabel(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetLabel,(self,) + _args, _kwargs)
        return val
    def SetLabel(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_SetLabel,(self,) + _args, _kwargs)
        return val
    def GetHelpString(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetHelpString,(self,) + _args, _kwargs)
        return val
    def SetHelpString(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_SetHelpString,(self,) + _args, _kwargs)
        return val
    def UpdateUI(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_UpdateUI,(self,) + _args, _kwargs)
        return val
    def Delete(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Delete,(self,) + _args, _kwargs)
        return val
    def DeleteItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_DeleteItem,(self,) + _args, _kwargs)
        return val
    def Remove(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Remove,(self,) + _args, _kwargs)
        return val
    def RemoveItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_RemoveItem,(self,) + _args, _kwargs)
        return val
    def Destroy(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_Destroy,(self,) + _args, _kwargs)
        return val
    def DestroyId(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_DestroyId,(self,) + _args, _kwargs)
        return val
    def DestroyItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_DestroyItem,(self,) + _args, _kwargs)
        return val
    def GetMenuItemCount(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetMenuItemCount,(self,) + _args, _kwargs)
        return val
    def GetMenuItems(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetMenuItems,(self,) + _args, _kwargs)
        return val
    def SetEventHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_SetEventHandler,(self,) + _args, _kwargs)
        return val
    def GetEventHandler(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetEventHandler,(self,) + _args, _kwargs)
        return val
    def SetInvokingWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_SetInvokingWindow,(self,) + _args, _kwargs)
        return val
    def GetInvokingWindow(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetInvokingWindow,(self,) + _args, _kwargs)
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetStyle,(self,) + _args, _kwargs)
        return val
    def IsAttached(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_IsAttached,(self,) + _args, _kwargs)
        return val
    def SetParent(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_SetParent,(self,) + _args, _kwargs)
        return val
    def GetParent(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenu_GetParent,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMenu instance at %s>" % (self.this,)
class wxMenu(wxMenuPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxMenu,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxMenuBarPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Append(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_Append,(self,) + _args, _kwargs)
        return val
    def Insert(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_Insert,(self,) + _args, _kwargs)
        return val
    def GetMenuCount(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_GetMenuCount,(self,) + _args, _kwargs)
        return val
    def GetMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_GetMenu,(self,) + _args, _kwargs)
        return val
    def Replace(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_Replace,(self,) + _args, _kwargs)
        return val
    def Remove(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_Remove,(self,) + _args, _kwargs)
        return val
    def EnableTop(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_EnableTop,(self,) + _args, _kwargs)
        return val
    def IsEnabledTop(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_IsEnabledTop,(self,) + _args, _kwargs)
        return val
    def SetLabelTop(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_SetLabelTop,(self,) + _args, _kwargs)
        return val
    def GetLabelTop(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_GetLabelTop,(self,) + _args, _kwargs)
        return val
    def FindMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_FindMenu,(self,) + _args, _kwargs)
        return val
    def FindMenuItem(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_FindMenuItem,(self,) + _args, _kwargs)
        return val
    def FindItemById(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_FindItemById,(self,) + _args, _kwargs)
        return val
    def Enable(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_Enable,(self,) + _args, _kwargs)
        return val
    def Check(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_Check,(self,) + _args, _kwargs)
        return val
    def IsChecked(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_IsChecked,(self,) + _args, _kwargs)
        return val
    def IsEnabled(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_IsEnabled,(self,) + _args, _kwargs)
        return val
    def SetLabel(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_SetLabel,(self,) + _args, _kwargs)
        return val
    def GetLabel(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_GetLabel,(self,) + _args, _kwargs)
        return val
    def SetHelpString(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_SetHelpString,(self,) + _args, _kwargs)
        return val
    def GetHelpString(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuBar_GetHelpString,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMenuBar instance at %s>" % (self.this,)
class wxMenuBar(wxMenuBarPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxMenuBar,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxMenuItemPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetMenu,(self,) + _args, _kwargs)
        return val
    def SetId(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_SetId,(self,) + _args, _kwargs)
        return val
    def GetId(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetId,(self,) + _args, _kwargs)
        return val
    def IsSeparator(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_IsSeparator,(self,) + _args, _kwargs)
        return val
    def SetText(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_SetText,(self,) + _args, _kwargs)
        return val
    def GetLabel(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetLabel,(self,) + _args, _kwargs)
        return val
    def GetText(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetText,(self,) + _args, _kwargs)
        return val
    def GetKind(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetKind,(self,) + _args, _kwargs)
        return val
    def SetCheckable(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_SetCheckable,(self,) + _args, _kwargs)
        return val
    def IsCheckable(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_IsCheckable,(self,) + _args, _kwargs)
        return val
    def IsSubMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_IsSubMenu,(self,) + _args, _kwargs)
        return val
    def SetSubMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_SetSubMenu,(self,) + _args, _kwargs)
        return val
    def GetSubMenu(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetSubMenu,(self,) + _args, _kwargs)
        return val
    def Enable(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_Enable,(self,) + _args, _kwargs)
        return val
    def IsEnabled(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_IsEnabled,(self,) + _args, _kwargs)
        return val
    def Check(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_Check,(self,) + _args, _kwargs)
        return val
    def IsChecked(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_IsChecked,(self,) + _args, _kwargs)
        return val
    def Toggle(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_Toggle,(self,) + _args, _kwargs)
        return val
    def SetHelp(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_SetHelp,(self,) + _args, _kwargs)
        return val
    def GetHelp(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetHelp,(self,) + _args, _kwargs)
        return val
    def GetAccel(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetAccel,(self,) + _args, _kwargs)
        if val: val = wxAcceleratorEntryPtr(val) 
        return val
    def SetAccel(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_SetAccel,(self,) + _args, _kwargs)
        return val
    def SetBitmap(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_SetBitmap,(self,) + _args, _kwargs)
        return val
    def GetBitmap(self, *_args, **_kwargs):
        val = apply(windowsc.wxMenuItem_GetBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) 
        return val
    def __repr__(self):
        return "<C wxMenuItem instance at %s>" % (self.this,)
class wxMenuItem(wxMenuItemPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windowsc.new_wxMenuItem,_args,_kwargs)
        self.thisown = 1






#-------------- FUNCTION WRAPPERS ------------------

def wxFindWindowById(*_args, **_kwargs):
    val = apply(windowsc.wxFindWindowById,_args,_kwargs)
    return val

def wxFindWindowByName(*_args, **_kwargs):
    val = apply(windowsc.wxFindWindowByName,_args,_kwargs)
    return val

def wxFindWindowByLabel(*_args, **_kwargs):
    val = apply(windowsc.wxFindWindowByLabel,_args,_kwargs)
    return val

wxValidator_IsSilent = windowsc.wxValidator_IsSilent

wxValidator_SetBellOnError = windowsc.wxValidator_SetBellOnError

def wxWindow_FindFocus(*_args, **_kwargs):
    val = apply(windowsc.wxWindow_FindFocus,_args,_kwargs)
    return val

wxWindow_NewControlId = windowsc.wxWindow_NewControlId

wxWindow_NextControlId = windowsc.wxWindow_NextControlId

wxWindow_PrevControlId = windowsc.wxWindow_PrevControlId

def wxWindow_GetCapture(*_args, **_kwargs):
    val = apply(windowsc.wxWindow_GetCapture,_args,_kwargs)
    return val

wxMenuItem_GetLabelFromText = windowsc.wxMenuItem_GetLabelFromText



#-------------- VARIABLE WRAPPERS ------------------




"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Logging.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx


class Log:
    """"""

    def Flush(self):
        """"""
        pass

    def GetVerbose(self):
        """"""
        pass

    def HasPendingMessages(self):
        """"""
        pass

    def TimeStamp(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PyLog(Log):
    """"""

    def Destroy(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass


class LogChain(Log):
    """"""

    def GetOldLog(self):
        """"""
        pass

    def IsPassingMessages(self):
        """"""
        pass

    def PassMessages(self):
        """"""
        pass

    def SetLog(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class LogGui(Log):
    """"""

    def __init__(self):
        """"""
        pass


class LogNull:
    """"""

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class LogStderr(Log):
    """"""

    def __init__(self):
        """"""
        pass


class LogTextCtrl(Log):
    """"""

    def __init__(self):
        """"""
        pass


class LogWindow(Log):
    """"""

    def GetFrame(self):
        """"""
        pass

    def GetOldLog(self):
        """"""
        pass

    def IsPassingMessages(self):
        """"""
        pass

    def PassMessages(self):
        """"""
        pass

    def Show(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass





"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Frames.py,v 1.1.2.2 2003/03/20 23:14:27 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
import Parameters as wx
from Window import TopLevelWindow, Window


class Frame(TopLevelWindow):
    """A frame is a window whose size and position can (usually) be
    changed by the user. It usually has thick borders and a title bar,
    and can optionally contain a menu bar, toolbar and status bar. A
    frame can contain any window that is not a frame or dialog.

    A frame that has a status bar and toolbar created via the
    CreateStatusBar/CreateToolBar functions manages these windows, and
    adjusts the value returned by GetClientSize to reflect the
    remaining size available to application windows.

    An application should normally define a CloseEvent handler for the
    frame to respond to system close events, for example so that
    related data and subwindows can be cleaned up."""

    def __init__(self, parent, id, title, pos=wx.DefaultPosition,
                 size=wx.DefaultSize, style=wx.DEFAULT_FRAME_STYLE,
                 name=wx.PyFrameNameStr):
        """Create a Frame instance.

        parent - The window parent. This may be NULL. If it is
        non-NULL, the frame will always be displayed on top of the
        parent window on Windows.

        id - The window identifier. It may take a value of -1 to
        indicate a default value.

        title - The caption to be displayed on the frame's title bar.

        pos - The window position. A value of (-1, -1) indicates a
        default position, chosen by either the windowing system or
        wxWindows, depending on platform.

        size - The window size. A value of (-1, -1) indicates a
        default size, chosen by either the windowing system or
        wxWindows, depending on platform.

        style - The window style.

        name - The name of the window. This parameter is used to
        associate a name with the item, allowing the application user
        to set Motif resource values for individual windows."""
        pass

    def Create(self, parent, id, title, pos=wx.DefaultPosition,
               size=wx.DefaultSize, style=wx.DEFAULT_FRAME_STYLE,
               name=wx.PyFrameNameStr):
        """Create a Frame instance."""
        pass

    def Command(self, id):
        """Simulate a menu command; id is a menu item identifier."""
        pass

    def CreateStatusBar(self, number=1, style=wx.ST_SIZEGRIP, id=-1,
                        name=wx.PyStatusLineNameStr):
        """Create a status bar at the bottom of frame.

        number - The number of fields to create. Specify a value
        greater than 1 to create a multi-field status bar.

        style - The status bar style. See wx.StatusBar for a list of
        valid styles.

        id - The status bar window identifier. If -1, an identifier
        will be chosen by wxWindows.

        name - The status bar window name.

        The width of the status bar is the whole width of the frame
        (adjusted automatically when resizing), and the height and
        text size are chosen by the host windowing system.

        By default, the status bar is an instance of wx.StatusBar."""
        pass

    def CreateToolBar(self, style=wx.NO_BORDER|wx.TB_HORIZONTAL, id=-1,
                      name=wx.PyToolBarNameStr):
        """Create a toolbar at the top or left of frame.

        style - The toolbar style. See wxToolBar for a list of valid
        styles.

        id - The toolbar window identifier. If -1, an identifier will
        be chosen by wxWindows.

        name - The toolbar window name.

        By default, the toolbar is an instance of wx.ToolBar (which is
        defined to be a suitable toolbar class on each platform, such
        as wx.ToolBar95).

        When a toolbar has been created with this function, or made
        known to the frame with wx.Frame.SetToolBar, the frame will
        manage the toolbar position and adjust the return value from
        wx.Window.GetClientSize to reflect the available space for
        application windows."""
        pass

    def DoGiveHelp(self, text, show):
        """Show help text (typically in the statusbar).

        show is False if you are hiding the help, True otherwise.

        Meant to be overridden if a derived frame wants to do
        something else with help text from menus and etc.  The default
        implementation simply calls Frame.SetStatusText."""
        pass

    def GetClientAreaOrigin(self):
        """Return origin of frame client area (in client coordinates).

        It may be different from (0, 0) if the frame has a toolbar."""
        pass

    def GetMenuBar(self):
        """Return menubar currently associated with frame (if any)."""
        pass

    def GetStatusBar(self):
        """Return status bar currently associated with frame (if any)."""
        pass

    def GetStatusBarPane(self):
        """Return status bar pane used to display menu and toolbar
        help."""
        pass

    def GetToolBar(self):
        """Return toolbar currently associated with frame (if any)."""
        pass

    def PopStatusText(self, number=0):
        """Redraw status bar with previous status text.

        number - The status field (starting from zero)."""
        pass

    def ProcessCommand(self, id):
        """Process menu command; return True if processed.

        id is the menu command identifier."""
        pass

    def PushStatusText(self, text, number=0):
        """Set status bar text and redraw status bar, remembering
        previous text.

        text - The text for the status field.

        number - The status field (starting from zero).

        Use an empty string to clear the status bar."""
        pass

    def SendSizeEvent(self):
        """Send a dummy size event to the frame forcing it to
        reevaluate its children positions. It is sometimes useful to
        call this function after adding or deleting a children after
        the frame creation or if a child size changes.

        Note that if the frame is using either sizers or constraints
        for the children layout, it is enough to call Frame.Layout()
        directly and this function should not be used in this case."""
        pass

    def SetMenuBar(self, menubar):
        """Show the menu bar in the frame.

        menuBar - The menu bar to associate with the frame.

        If the frame is destroyed, the menu bar and its menus will be
        destroyed also, so do not delete the menu bar explicitly
        (except by resetting the frame's menu bar to another frame or
        NULL).

        Under Windows, a call to Frame.OnSize is generated, so be sure
        to initialize data members properly before calling SetMenuBar.

        Note that it is not possible to call this function twice for
        the same frame object."""
        pass

    def SetStatusBar(self, statBar):
        """Associate a status bar with the frame."""
        pass

    def SetStatusBarPane(self, n):
        """Set the status bar pane used to display menu and toolbar
        help.  Using -1 disables help display."""
        pass

    def SetStatusText(self, text, number=0):
        """Set status bar text and redraw status bar.

        text - The text for the status field.

        number - The status field (starting from zero).

        Use an empty string to clear the status bar."""
        pass

    def SetStatusWidths(self, choices):
        """Sets the widths of the fields in the status bar.

        choices - a Python list of integers, each of which is a status
        field width in pixels. A value of -1 indicates that the field
        is variable width; at least one field must be -1.

        The widths of the variable fields are calculated from the
        total width of all fields, minus the sum of widths of the
        non-variable fields, divided by the number of variable fields."""
        pass

    def SetToolBar(self, toolbar):
        """Associate a toolbar with the frame."""
        pass


class LayoutAlgorithm(Object):
    """"""

    def __init__(self):
        """"""
        pass

    def LayoutFrame(self):
        """"""
        pass

    def LayoutMDIFrame(self):
        """"""
        pass

    def LayoutWindow(self):
        """"""
        pass


class MDIChildFrame(Frame):
    """"""

    def __init__(self):
        """"""
        pass

    def Create(self):
        """"""
        pass

    def Activate(self):
        """"""
        pass

    def Maximize(self):
        """"""
        pass

    def Restore(self):
        """"""
        pass


class MDIClientWindow(Window):
    """"""

    def __init__(self):
        """"""
        pass

    def Create(self):
        """"""
        pass


class MDIParentFrame(Frame):
    """"""

    def __init__(self):
        """"""
        pass

    def Create(self):
        """"""
        pass

    def ActivateNext(self):
        """"""
        pass

    def ActivatePrevious(self):
        """"""
        pass

    def ArrangeIcons(self):
        """"""
        pass

    def Cascade(self):
        """"""
        pass

    def GetActiveChild(self):
        """"""
        pass

    def GetClientWindow(self):
        """"""
        pass

    def GetToolBar(self):
        """"""
        pass

    def Tile(self):
        """"""
        pass


class MiniFrame(Frame):
    """"""

    def __init__(self):
        """"""
        pass

    def Create(self):
        """"""
        pass


class SplashScreen(Frame):
    """"""

    def __init__(self):
        """"""
        pass

    def GetSplashStyle(self):
        """"""
        pass

    def GetSplashWindow(self):
        """"""
        pass

    def GetTimeout(self):
        """"""
        pass


class SplashScreenWindow(Window):
    """"""

    def __init__(self):
        """"""
        pass

    def GetBitmap(self):
        """"""
        pass

    def SetBitmap(self):
        """"""
        pass


class StatusBar(Window):
    """"""

    def __init__(self):
        """"""
        pass

    def Create(self):
        """"""
        pass

    def GetBorderX(self):
        """"""
        pass

    def GetBorderY(self):
        """"""
        pass

    def GetFieldRect(self):
        """"""
        pass

    def GetFieldsCount(self):
        """"""
        pass

    def GetStatusText(self):
        """"""
        pass

    def PopStatusText(self):
        """"""
        pass

    def PushStatusText(self):
        """"""
        pass

    def SetFieldsCount(self):
        """"""
        pass

    def SetMinHeight(self):
        """"""
        pass

    def SetStatusText(self):
        """"""
        pass

    def SetStatusWidths(self):
        """"""
        pass



# This file was created automatically by SWIG.
import framesc

from misc import *

from gdi import *

from fonts import *

from windows import *

from clip_dnd import *

from stattool import *

from controls import *

from events import *
import wx
class wxTopLevelWindowPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_Create,(self,) + _args, _kwargs)
        return val
    def Maximize(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_Maximize,(self,) + _args, _kwargs)
        return val
    def Restore(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_Restore,(self,) + _args, _kwargs)
        return val
    def Iconize(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_Iconize,(self,) + _args, _kwargs)
        return val
    def IsMaximized(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_IsMaximized,(self,) + _args, _kwargs)
        return val
    def IsIconized(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_IsIconized,(self,) + _args, _kwargs)
        return val
    def GetIcon(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_GetIcon,(self,) + _args, _kwargs)
        if val: val = wxIconPtr(val) ; val.thisown = 1
        return val
    def SetIcon(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_SetIcon,(self,) + _args, _kwargs)
        return val
    def SetIcons(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_SetIcons,(self,) + _args, _kwargs)
        return val
    def ShowFullScreen(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_ShowFullScreen,(self,) + _args, _kwargs)
        return val
    def IsFullScreen(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_IsFullScreen,(self,) + _args, _kwargs)
        return val
    def SetTitle(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_SetTitle,(self,) + _args, _kwargs)
        return val
    def GetTitle(self, *_args, **_kwargs):
        val = apply(framesc.wxTopLevelWindow_GetTitle,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTopLevelWindow instance at %s>" % (self.this,)
class wxTopLevelWindow(wxTopLevelWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(framesc.new_wxTopLevelWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreTopLevelWindow(*_args,**_kwargs):
    val = wxTopLevelWindowPtr(apply(framesc.new_wxPreTopLevelWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxFramePtr(wxTopLevelWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_Create,(self,) + _args, _kwargs)
        return val
    def GetClientAreaOrigin(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_GetClientAreaOrigin,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def SetMenuBar(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_SetMenuBar,(self,) + _args, _kwargs)
        return val
    def GetMenuBar(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_GetMenuBar,(self,) + _args, _kwargs)
        return val
    def ProcessCommand(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_ProcessCommand,(self,) + _args, _kwargs)
        return val
    def CreateStatusBar(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_CreateStatusBar,(self,) + _args, _kwargs)
        return val
    def GetStatusBar(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_GetStatusBar,(self,) + _args, _kwargs)
        return val
    def SetStatusBar(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_SetStatusBar,(self,) + _args, _kwargs)
        return val
    def SetStatusText(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_SetStatusText,(self,) + _args, _kwargs)
        return val
    def SetStatusWidths(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_SetStatusWidths,(self,) + _args, _kwargs)
        return val
    def PushStatusText(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_PushStatusText,(self,) + _args, _kwargs)
        return val
    def PopStatusText(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_PopStatusText,(self,) + _args, _kwargs)
        return val
    def DoGiveHelp(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_DoGiveHelp,(self,) + _args, _kwargs)
        return val
    def SetStatusBarPane(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_SetStatusBarPane,(self,) + _args, _kwargs)
        return val
    def GetStatusBarPane(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_GetStatusBarPane,(self,) + _args, _kwargs)
        return val
    def CreateToolBar(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_CreateToolBar,(self,) + _args, _kwargs)
        return val
    def GetToolBar(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_GetToolBar,(self,) + _args, _kwargs)
        return val
    def SetToolBar(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_SetToolBar,(self,) + _args, _kwargs)
        return val
    def SendSizeEvent(self, *_args, **_kwargs):
        val = apply(framesc.wxFrame_SendSizeEvent,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFrame instance at %s>" % (self.this,)
    Command = ProcessCommand
class wxFrame(wxFramePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(framesc.new_wxFrame,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreFrame(*_args,**_kwargs):
    val = wxFramePtr(apply(framesc.new_wxPreFrame,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxDialogPtr(wxTopLevelWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_Create,(self,) + _args, _kwargs)
        return val
    def Centre(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_Centre,(self,) + _args, _kwargs)
        return val
    def EndModal(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_EndModal,(self,) + _args, _kwargs)
        return val
    def SetModal(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_SetModal,(self,) + _args, _kwargs)
        return val
    def IsModal(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_IsModal,(self,) + _args, _kwargs)
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def GetReturnCode(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_GetReturnCode,(self,) + _args, _kwargs)
        return val
    def SetReturnCode(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_SetReturnCode,(self,) + _args, _kwargs)
        return val
    def CreateTextSizer(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_CreateTextSizer,(self,) + _args, _kwargs)
        return val
    def CreateButtonSizer(self, *_args, **_kwargs):
        val = apply(framesc.wxDialog_CreateButtonSizer,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDialog instance at %s>" % (self.this,)
class wxDialog(wxDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(framesc.new_wxDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreDialog(*_args,**_kwargs):
    val = wxDialogPtr(apply(framesc.new_wxPreDialog,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxMiniFramePtr(wxFramePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(framesc.wxMiniFrame_Create,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMiniFrame instance at %s>" % (self.this,)
class wxMiniFrame(wxMiniFramePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(framesc.new_wxMiniFrame,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreMiniFrame(*_args,**_kwargs):
    val = wxMiniFramePtr(apply(framesc.new_wxPreMiniFrame,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxSplashScreenWindowPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetBitmap(self, *_args, **_kwargs):
        val = apply(framesc.wxSplashScreenWindow_SetBitmap,(self,) + _args, _kwargs)
        return val
    def GetBitmap(self, *_args, **_kwargs):
        val = apply(framesc.wxSplashScreenWindow_GetBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) 
        return val
    def __repr__(self):
        return "<C wxSplashScreenWindow instance at %s>" % (self.this,)
class wxSplashScreenWindow(wxSplashScreenWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(framesc.new_wxSplashScreenWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxSplashScreenPtr(wxFramePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetSplashStyle(self, *_args, **_kwargs):
        val = apply(framesc.wxSplashScreen_GetSplashStyle,(self,) + _args, _kwargs)
        return val
    def GetSplashWindow(self, *_args, **_kwargs):
        val = apply(framesc.wxSplashScreen_GetSplashWindow,(self,) + _args, _kwargs)
        if val: val = wxSplashScreenWindowPtr(val) 
        return val
    def GetTimeout(self, *_args, **_kwargs):
        val = apply(framesc.wxSplashScreen_GetTimeout,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSplashScreen instance at %s>" % (self.this,)
class wxSplashScreen(wxSplashScreenPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(framesc.new_wxSplashScreen,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxFULLSCREEN_NOMENUBAR = framesc.wxFULLSCREEN_NOMENUBAR
wxFULLSCREEN_NOTOOLBAR = framesc.wxFULLSCREEN_NOTOOLBAR
wxFULLSCREEN_NOSTATUSBAR = framesc.wxFULLSCREEN_NOSTATUSBAR
wxFULLSCREEN_NOBORDER = framesc.wxFULLSCREEN_NOBORDER
wxFULLSCREEN_NOCAPTION = framesc.wxFULLSCREEN_NOCAPTION
wxFULLSCREEN_ALL = framesc.wxFULLSCREEN_ALL
wxTOPLEVEL_EX_DIALOG = framesc.wxTOPLEVEL_EX_DIALOG
wxSPLASH_CENTRE_ON_PARENT = framesc.wxSPLASH_CENTRE_ON_PARENT
wxSPLASH_CENTRE_ON_SCREEN = framesc.wxSPLASH_CENTRE_ON_SCREEN
wxSPLASH_NO_CENTRE = framesc.wxSPLASH_NO_CENTRE
wxSPLASH_TIMEOUT = framesc.wxSPLASH_TIMEOUT
wxSPLASH_NO_TIMEOUT = framesc.wxSPLASH_NO_TIMEOUT



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Dialogs.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
from Frames import Frame
import Parameters as wx
from Window import TopLevelWindow


class Dialog(TopLevelWindow):
    """"""

    def Centre(self):
        """"""
        pass

    def Create(self):
        """"""
        pass

    def CreateButtonSizer(self):
        """"""
        pass

    def CreateTextSizer(self):
        """"""
        pass

    def EndModal(self):
        """"""
        pass

    def GetReturnCode(self):
        """"""
        pass

    def IsModal(self):
        """"""
        pass

    def SetModal(self):
        """"""
        pass

    def SetReturnCode(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ColourDialog(Dialog):
    """"""

    def GetColourData(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ColourData(Object):
    """"""

    def GetChooseFull(self):
        """"""
        pass

    def GetColour(self):
        """"""
        pass

    def GetCustomColour(self):
        """"""
        pass

    def SetChooseFull(self):
        """"""
        pass

    def SetColour(self):
        """"""
        pass

    def SetCustomColour(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ColourDatabase(Object):
    """"""

    def Append(self):
        """"""
        pass

    def FindColour(self):
        """"""
        pass

    def FindName(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DirDialog(Dialog):
    """"""

    def GetMessage(self):
        """"""
        pass

    def GetPath(self):
        """"""
        pass

    def GetStyle(self):
        """"""
        pass

    def SetMessage(self):
        """"""
        pass

    def SetPath(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FileDialog(Dialog):
    """"""

    def GetDirectory(self):
        """"""
        pass

    def GetFilename(self):
        """"""
        pass

    def GetFilenames(self):
        """"""
        pass

    def GetFilterIndex(self):
        """"""
        pass

    def GetMessage(self):
        """"""
        pass

    def GetPath(self):
        """"""
        pass

    def GetPaths(self):
        """"""
        pass

    def GetStyle(self):
        """"""
        pass

    def GetWildcard(self):
        """"""
        pass

    def SetDirectory(self):
        """"""
        pass

    def SetFilename(self):
        """"""
        pass

    def SetFilterIndex(self):
        """"""
        pass

    def SetMessage(self):
        """"""
        pass

    def SetPath(self):
        """"""
        pass

    def SetStyle(self):
        """"""
        pass

    def SetWildcard(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FindReplaceDialog(Dialog):
    """"""

    def Create(self):
        """"""
        pass

    def GetData(self):
        """"""
        pass

    def SetData(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FindReplaceData(Object):
    """"""

    def GetFindString(self):
        """"""
        pass

    def GetFlags(self):
        """"""
        pass

    def GetReplaceString(self):
        """"""
        pass

    def SetFindString(self):
        """"""
        pass

    def SetFlags(self):
        """"""
        pass

    def SetReplaceString(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FontDialog(Dialog):
    """"""

    def GetFontData(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FontData(Object):
    """"""

    def EnableEffects(self):
        """"""
        pass

    def GetAllowSymbols(self):
        """"""
        pass

    def GetChosenFont(self):
        """"""
        pass

    def GetColour(self):
        """"""
        pass

    def GetEnableEffects(self):
        """"""
        pass

    def GetInitialFont(self):
        """"""
        pass

    def GetShowHelp(self):
        """"""
        pass

    def SetAllowSymbols(self):
        """"""
        pass

    def SetChosenFont(self):
        """"""
        pass

    def SetColour(self):
        """"""
        pass

    def SetInitialFont(self):
        """"""
        pass

    def SetRange(self):
        """"""
        pass

    def SetShowHelp(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class MessageDialog(Dialog):
    """"""

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass



class MultiChoiceDialog(Dialog):
    """"""

    def GetSelections(self):
        """"""
        pass

    def SetSelections(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ProgressDialog(Frame):
    """"""

    def Resume(self):
        """"""
        pass

    def Update(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SingleChoiceDialog(Dialog):
    """"""

    def GetSelection(self):
        """"""
        pass

    def GetStringSelection(self):
        """"""
        pass

    def SetSelection(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class TextEntryDialog(Dialog):
    """"""

    def GetValue(self):
        """"""
        pass

    def SetValue(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass



#----------------------------------------------------------------------------
# Name:         GridColMover.py
# Purpose:      Grid Column Mover Extension
#
# Author:       Gerrit van Dyk (email: gerritvd@decillion.net)
#
# Version       0.1
# Date:         Nov 19, 2002
# RCS-ID:       $Id: gridmovers.py,v 1.1.2.2 2003/02/26 18:38:15 RD Exp $
# Licence:      wxWindows license
#----------------------------------------------------------------------------

from wxPython.wx import *
from wxPython.grid import wxGridPtr

#----------------------------------------------------------------------------
# event class and macors


wxEVT_COMMAND_GRID_COL_MOVE = wxNewEventType()
wxEVT_COMMAND_GRID_ROW_MOVE = wxNewEventType()

def EVT_GRID_COL_MOVE(win, id, func):
    win.Connect(id, -1, wxEVT_COMMAND_GRID_COL_MOVE, func)

def EVT_GRID_ROW_MOVE(win,id,func):
    win.Connect(id, -1, wxEVT_COMMAND_GRID_ROW_MOVE, func)


class wxGridColMoveEvent(wxPyCommandEvent):
    def __init__(self, id, dCol, bCol):
        wxPyCommandEvent.__init__(self, id = id)
        self.SetEventType(wxEVT_COMMAND_GRID_COL_MOVE)
        self.moveColumn = dCol
        self.beforeColumn = bCol

    def GetMoveColumn(self):
        return self.moveColumn

    def GetBeforeColumn(self):
        return self.beforeColumn


class wxGridRowMoveEvent(wxPyCommandEvent):
    def __init__(self, id, dRow, bRow):
        wxPyCommandEvent.__init__(self,id = id)
        self.SetEventType(wxEVT_COMMAND_GRID_ROW_MOVE)
        self.moveRow = dRow
        self.beforeRow = bRow

    def GetMoveRow(self):
        return self.moveRow

    def GetBeforeRow(self):
        return self.beforeRow


#----------------------------------------------------------------------------
# graft new methods into the wxGridPtr class

def _ColToRect(self,col):
    if self.GetNumberRows() > 0:
        rect = self.CellToRect(0,col)
    else:
        rect = wxRect()
        rect.height = self.GetColLabelSize()
        rect.width = self.GetColSize(col)
        for cCol in range(0,col):
            rect.x += self.GetColSize(cCol)
    rect.y = self.GetGridColLabelWindow().GetPosition()[1]
    return rect

wxGridPtr.ColToRect = _ColToRect


def _RowToRect(self,row):
    if self.GetNumberCols() > 0:
        rect = self.CellToRect(row,0)
    else:
        rect = wxRect()
        rect.width = self.GetRowLabelSize()
        rect.height = self.GetRowSize(row)
        for cRow in range(0,row):
            rect.y += self.GetRowSize(cRow)
    rect.x = self.GetGridRowLabelWindow().GetPosition()[0]
    return rect

wxGridPtr.RowToRect = _RowToRect


#----------------------------------------------------------------------------

class ColDragWindow(wxWindow):
    def __init__(self,parent,image,dragCol):
        wxWindow.__init__(self,parent,wxSIMPLE_BORDER)
        self.image = image
        self.SetSize((self.image.GetWidth(),self.image.GetHeight()))
        self.ux = parent.GetScrollPixelsPerUnit()[0]
        self.moveColumn = dragCol

        EVT_PAINT(self,self.OnPaint)

    def DisplayAt(self,pos,y):
        x = self.GetPositionTuple()[0]
        if x == pos:
            self.Refresh()              # Need to display insertion point
        else:
            self.MoveXY(pos,y)

    def GetMoveColumn(self):
        return self.moveColumn

    def _GetInsertionInfo(self):
        parent = self.GetParent()
        sx = parent.GetViewStart()[0] * self.ux
        sx -= parent._rlSize
        x = self.GetPositionTuple()[0]
        w = self.GetSizeTuple()[0]
        sCol = parent.XToCol(x + sx)
        eCol = parent.XToCol(x + w + sx)
        iPos = xPos = xCol = 99999
        centerPos = x + sx + (w / 2)
        for col in range(sCol,eCol + 1):
            cx = parent.ColToRect(col)[0]
            if abs(cx - centerPos) < iPos:
                iPos = abs(cx - centerPos)
                xCol = col
                xPos = cx
        if xCol < 0 or xCol > parent.GetNumberCols():
            xCol = parent.GetNumberCols()
        return (xPos - sx - x,xCol)

    def GetInsertionColumn(self):
        return self._GetInsertionInfo()[1]

    def GetInsertionPos(self):
        return self._GetInsertionInfo()[0]

    def OnPaint(self,evt):
        dc = wxPaintDC(self)
        w,h = self.GetSize()
        dc.DrawBitmap(self.image,0,0)
        dc.SetPen(wxPen(wxBLACK,1,wxSOLID))
        dc.SetBrush(wxTRANSPARENT_BRUSH)
        dc.DrawRectangle(0,0,w,h)
        iPos = self.GetInsertionPos()
        dc.DrawLine(iPos,h - 10,iPos,h)




class RowDragWindow(wxWindow):
    def __init__(self,parent,image,dragRow):
        wxWindow.__init__(self,parent,wxSIMPLE_BORDER)
        self.image = image
        self.SetSize((self.image.GetWidth(),self.image.GetHeight()))
        self.uy = parent.GetScrollPixelsPerUnit()[1]
        self.moveRow = dragRow

        EVT_PAINT(self,self.OnPaint)

    def DisplayAt(self,x,pos):
        y = self.GetPositionTuple()[1]
        if y == pos:
            self.Refresh()              # Need to display insertion point
        else:
            self.MoveXY(x,pos)

    def GetMoveRow(self):
        return self.moveRow

    def _GetInsertionInfo(self):
        parent = self.GetParent()
        sy = parent.GetViewStart()[1] * self.uy
        sy -= parent._clSize
        y = self.GetPositionTuple()[1]
        h = self.GetSizeTuple()[1]
        sRow = parent.YToRow(y + sy)
        eRow = parent.YToRow(y + h + sy)
        iPos = yPos = yRow = 99999
        centerPos = y + sy + (h / 2)
        for row in range(sRow,eRow + 1):
            cy = parent.RowToRect(row)[1]
            if abs(cy - centerPos) < iPos:
                iPos = abs(cy - centerPos)
                yRow = row
                yPos = cy
        if yRow < 0 or yRow > parent.GetNumberRows():
            yRow = parent.GetNumberRows()
        return (yPos - sy - y,yRow)

    def GetInsertionRow(self):
        return self._GetInsertionInfo()[1]

    def GetInsertionPos(self):
        return self._GetInsertionInfo()[0]

    def OnPaint(self,evt):
        dc = wxPaintDC(self)
        w,h = self.GetSize()
        dc.DrawBitmap(self.image,0,0)
        dc.SetPen(wxPen(wxBLACK,1,wxSOLID))
        dc.SetBrush(wxTRANSPARENT_BRUSH)
        dc.DrawRectangle(0,0,w,h)
        iPos = self.GetInsertionPos()
        dc.DrawLine(w - 10,iPos,w,iPos)

#----------------------------------------------------------------------------

class wxGridColMover(wxEvtHandler):
    def __init__(self,grid):
        wxEvtHandler.__init__(self)

        self.grid = grid
        self.grid._rlSize = self.grid.GetRowLabelSize()
        self.lwin = grid.GetGridColLabelWindow()
        self.lwin.PushEventHandler(self)
        self.colWin = None
        self.ux = self.grid.GetScrollPixelsPerUnit()[0]
        self.startX = -10
        self.cellX = 0
        self.didMove = False
        self.isDragging = False

        EVT_MOTION(self,self.OnMouseMove)
        EVT_LEFT_DOWN(self,self.OnPress)
        EVT_LEFT_UP(self,self.OnRelease)

    def OnMouseMove(self,evt):
        if self.isDragging:
            if abs(self.startX - evt.m_x) >= 3:
                self.didMove = True
                sx,y = self.grid.GetViewStart()
                w,h = self.lwin.GetClientSizeTuple()
                x = sx * self.ux
                if (evt.m_x + x) < x:
                    x = evt.m_x + x
                elif evt.m_x > w:
                    x += evt.m_x - w
                if x < 1: x = 0
                else: x /= self.ux
                if x != sx:
                    if wxPlatform == '__WXMSW__':
                        self.colWin.Show(False)
                    self.grid.Scroll(x,y)
                x,y = self.lwin.ClientToScreenXY(evt.m_x,0)
                x,y = self.grid.ScreenToClientXY(x,y)
                if not self.colWin.IsShown():
                    self.colWin.Show(True)
                px = x - self.cellX
                if px < 0 + self.grid._rlSize: px = 0 + self.grid._rlSize
                if px > w - self.colWin.GetSizeTuple()[0] + self.grid._rlSize:
                    px = w - self.colWin.GetSizeTuple()[0] + self.grid._rlSize
                self.colWin.DisplayAt(px,y)
                return
        evt.Skip()

    def OnPress(self,evt):
        self.startX = evt.m_x
        sx = self.grid.GetViewStart()[0] * self.ux
        sx -= self.grid._rlSize
        px,py = self.lwin.ClientToScreenXY(evt.m_x,evt.m_y)
        px,py = self.grid.ScreenToClientXY(px,py)
        if self.grid.XToEdgeOfCol(px + sx) != wxNOT_FOUND:
            evt.Skip()
            return

        self.isDragging = True
        self.didMove = False
        col = self.grid.XToCol(px + sx)
        rect = self.grid.ColToRect(col)
        self.cellX = px + sx - rect.x
        size = self.lwin.GetSizeTuple()
        rect.y = 0
        rect.x -= sx + self.grid._rlSize
        rect.height = size[1]
        colImg = self._CaptureImage(rect)
        self.colWin = ColDragWindow(self.grid,colImg,col)
        self.colWin.Show(False)
        self.lwin.CaptureMouse()

    def OnRelease(self,evt):
        if self.isDragging:
            self.lwin.ReleaseMouse()
            self.colWin.Show(False)
            self.isDragging = False
            if not self.didMove:
                px = self.lwin.ClientToScreenXY(self.startX,0)[0]
                px = self.grid.ScreenToClientXY(px,0)[0]
                sx = self.grid.GetViewStart()[0] * self.ux
                sx -= self.grid._rlSize
                col = self.grid.XToCol(px+sx)
                if col != wxNOT_FOUND:
                    self.grid.SelectCol(col,evt.m_controlDown)
                return
            else:
                bCol = self.colWin.GetInsertionColumn()
                dCol = self.colWin.GetMoveColumn()
                wxPostEvent(self,wxGridColMoveEvent(self.grid.GetId(),
                                                    dCol,bCol))
            self.colWin.Destroy()
        evt.Skip()

    def _CaptureImage(self,rect):
        bmp = wxEmptyBitmap(rect.width,rect.height)
        memdc = wxMemoryDC()
        memdc.SelectObject(bmp)
        dc = wxWindowDC(self.lwin)
        memdc.Blit(0,0,rect.width,rect.height,dc,rect.x,rect.y)
        memdc.SelectObject(wxNullBitmap)
        return bmp



class wxGridRowMover(wxEvtHandler):
    def __init__(self,grid):
        wxEvtHandler.__init__(self)

        self.grid = grid
        self.grid._clSize = self.grid.GetColLabelSize()
        self.lwin = grid.GetGridRowLabelWindow()
        self.lwin.PushEventHandler(self)
        self.rowWin = None
        self.uy = self.grid.GetScrollPixelsPerUnit()[1]
        self.startY = -10
        self.cellY = 0
        self.didMove = False
        self.isDragging = False

        EVT_MOTION(self,self.OnMouseMove)
        EVT_LEFT_DOWN(self,self.OnPress)
        EVT_LEFT_UP(self,self.OnRelease)

    def OnMouseMove(self,evt):
        if self.isDragging:
            if abs(self.startY - evt.m_y) >= 3:
                self.didMove = True
                x,sy = self.grid.GetViewStart()
                w,h = self.lwin.GetClientSizeTuple()
                y = sy * self.uy
                if (evt.m_y + y) < y:
                    y = evt.m_y + y
                elif evt.m_y > h:
                    y += evt.m_y - h
                if y < 1: y = 0
                else: y /= self.uy
                if y != sy:
                    if wxPlatform == '__WXMSW__':
                        self.rowWin.Show(False)
                    self.grid.Scroll(x,y)
                x,y = self.lwin.ClientToScreenXY(0,evt.m_y)
                x,y = self.grid.ScreenToClientXY(x,y)
                if not self.rowWin.IsShown():
                    self.rowWin.Show(True)
                py = y - self.cellY
                if py < 0 + self.grid._clSize: py = 0 + self.grid._clSize
                if py > h - self.rowWin.GetSizeTuple()[1] + self.grid._clSize:
                    py = h - self.rowWin.GetSizeTuple()[1] + self.grid._clSize
                self.rowWin.DisplayAt(x,py)
                return
        evt.Skip()

    def OnPress(self,evt):
        self.startY = evt.m_y
        sy = self.grid.GetViewStart()[1] * self.uy
        sy -= self.grid._clSize
        px,py = self.lwin.ClientToScreenXY(evt.m_x,evt.m_y)
        px,py = self.grid.ScreenToClientXY(px,py)
        if self.grid.YToEdgeOfRow(py + sy) != wxNOT_FOUND:
            evt.Skip()
            return

        self.isDragging = True
        self.didMove = False
        row = self.grid.YToRow(py + sy)
        rect = self.grid.RowToRect(row)
        self.cellY = py + sy - rect.y
        size = self.lwin.GetSizeTuple()
        rect.x = 0
        rect.y -= sy + self.grid._clSize
        rect.width = size[0]
        rowImg = self._CaptureImage(rect)
        self.rowWin = RowDragWindow(self.grid,rowImg,row)
        self.rowWin.Show(False)
        self.lwin.CaptureMouse()

    def OnRelease(self,evt):
        if self.isDragging:
            self.lwin.ReleaseMouse()
            self.rowWin.Show(False)
            self.isDragging = False
            if not self.didMove:
                py = self.lwin.ClientToScreenXY(0,self.startY)[1]
                py = self.grid.ScreenToClientXY(0,py)[1]
                sy = self.grid.GetViewStart()[1] * self.uy
                sy -= self.grid._clSize
                row = self.grid.YToRow(py + sy)
                if row != wxNOT_FOUND:
                    self.grid.SelectRow(row,evt.m_controlDown)
                return
            else:
                bRow = self.rowWin.GetInsertionRow()
                dRow = self.rowWin.GetMoveRow()
                wxPostEvent(self,wxGridRowMoveEvent(self.grid.GetId(),
                                                    dRow,bRow))
            self.rowWin.Destroy()
        evt.Skip()

    def _CaptureImage(self,rect):
        bmp = wxEmptyBitmap(rect.width,rect.height)
        memdc = wxMemoryDC()
        memdc.SelectObject(bmp)
        dc = wxWindowDC(self.lwin)
        memdc.Blit(0,0,rect.width,rect.height,dc,rect.x,rect.y)
        memdc.SelectObject(wxNullBitmap)
        return bmp


#----------------------------------------------------------------------------
